@@ -3,7 +3,7 @@ package Promise::ES6;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.07_1';
 
 use constant {
 
@@ -102,10 +102,7 @@ L<this one|https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Using_p
 Promise::ES6 serves much the same role as L<Future> but exposes
 a standard, cross-language API rather than a proprietary one.
 
-CPAN contains a number of other modules that implement promises.
-Promise::ES6’s distinguishing features are simplicity and lightness.
-By design, it implements B<just> the standard Promise API and doesn’t
-assume you use, e.g., L<AnyEvent>.
+=back
 
 =cut
 
